==> 0.10.1.tar.gz: lib/bloc/rewards_module/pages/add_cash_approvers.dart <==


import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../../../utils/colors.dart';
import '../../../utils/custom_app_bar.dart';
import '../../../utils/custom_tab_maker.dart';
import '../../../utils/hexColors.dart';
import '../../../utils/localization.dart';
import '../../../utils/locator.dart';
import '../../../utils/text_styling.dart';
import '../../cubits/cubit_main.dart';
import 'member_page.dart';

// ignore: must_be_immutable
class AddCashApprovePage extends StatefulWidget {



  AddCashApprovePageState createState() => AddCashApprovePageState();
}

class AddCashApprovePageState extends State<AddCashApprovePage>
    with SingleTickerProviderStateMixin {
  List<CustomTabMaker>? list = [];
  late TabController _tabController;
  late TextStyleElements styleElements;
  List<PopupMenuItem>? menuItems;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();
  String? ownerType;
  int? ownerId;

  int _currentPosition = 0;
  String? pageTitle;
  late Null Function() callback;
  String? imageUrl;
  List<PopupMenuItem> menuList = [];
  List<Widget> invitePartnerList = [];

  List<Widget> invitePartnerEmployeeList = [];
  String? type;

  bool isMultiSelectEnabled = false;

  @override
  void initState() {
    super.initState();


  }




  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        resizeToAvoidBottomInset: true,
        backgroundColor: HexColor(AppColors.appColorBackground),

        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle: AppLocalizationsRewards.of(context)!.translate('cash_pp'),
            actions: [Padding(
              padding: const EdgeInsets.all(16.0),
              child:   Wrap(
                direction: Axis.horizontal,
                crossAxisAlignment: WrapCrossAlignment.center,
                children: [
                  Text(
                    AppLocalizationsRewards.of(context)!.translate('next'),
                    style: styleElements
                        .headline6ThemeScalableW(context)
                        .copyWith(color: HexColor(AppColors.blueApp)),
                  ),
                  Icon(Icons.keyboard_arrow_right,
                      color: HexColor(AppColors.blueApp))
                ],
              ),
            ),],
            onBackButtonPress: () {
              Navigator.pop(context);
            }),




        body:MemberPage(
          isAddMember:true,
          callBack: () {

          },
          multiSelectionEnabled: (val) {
            setState(() {
              isMultiSelectEnabled = val;
            });
          },
          key: null,
          type: "contacts", ownerId: 9, isUserAdmin: true,
        ),
      ),
    );
  }


}

==> 0.11.1.tar.gz: lib/bloc/rewards_module/pages/add_cash_approvers.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

import '../../../utils/colors.dart';
import '../../../utils/custom_app_bar.dart';
import '../../../utils/custom_tab_maker.dart';
import '../../../utils/hexColors.dart';
import '../../../utils/localization.dart';
import '../../../utils/locator.dart';
import '../../../utils/text_styling.dart';
import '../../cubits/cubit_main.dart';
import 'member_page.dart';

// ignore: must_be_immutable
class AddCashApprovePage extends StatefulWidget {
  AddCashApprovePageState createState() => AddCashApprovePageState();
}

class AddCashApprovePageState extends State<AddCashApprovePage>
    with SingleTickerProviderStateMixin {
  List<CustomTabMaker>? list = [];
  late TabController _tabController;
  late TextStyleElements styleElements;
  List<PopupMenuItem>? menuItems;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();
  String? ownerType;
  int? ownerId;

  int _currentPosition = 0;
  String? pageTitle;
  late Null Function() callback;
  String? imageUrl;
  List<PopupMenuItem> menuList = [];
  List<Widget> invitePartnerList = [];

  List<Widget> invitePartnerEmployeeList = [];
  String? type;

  bool isMultiSelectEnabled = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        resizeToAvoidBottomInset: true,
        backgroundColor: HexColor(AppColors.appColorBackground),
        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle:
                AppLocalizationsRewards.of(context)!.translate('cash_pp'),
            actions: [
              Padding(
                padding: const EdgeInsets.all(16.0),
                child: Wrap(
                  direction: Axis.horizontal,
                  crossAxisAlignment: WrapCrossAlignment.center,
                  children: [
                    Text(
                      AppLocalizationsRewards.of(context)!.translate('next'),
                      style: styleElements
                          .headline6ThemeScalableW(context)
                          .copyWith(color: HexColor(AppColors.blueApp)),
                    ),
                    Icon(Icons.keyboard_arrow_right,
                        color: HexColor(AppColors.blueApp))
                  ],
                ),
              ),
            ], onBackButtonPress: () {
          Navigator.pop(context);
        }),
        body: MemberPage(
          isAddMember: true,
          callBack: () {},
          multiSelectionEnabled: (val) {
            setState(() {
              isMultiSelectEnabled = val;
            });
          },
          key: null,
          type: "contacts",
          ownerId: 9,
          isUserAdmin: true,
        ),
      ),
    );
  }
}
